@@ -737,6 +737,8 @@ def plot_defect_densities(plot_params_in={}):
                 if len(d1["line_color"])==0:
                     d1["line_color"]=default_color[icolor]
                     icolor+=1
+                    if icolor==len(default_color):
+                        icolor=0
                 if len(d1["line_style"])==0:
                     d1["line_style"]="-"
                 if len(d1["line_width"])==0:
@@ -765,6 +767,8 @@ def plot_defect_densities(plot_params_in={}):
                 if len(d1["line_color"])==0:
                     d1["line_color"]=default_color[icolor]
                     icolor+=1
+                    if icolor==len(default_color):
+                        icolor=0
                 if len(d1["line_style"])==0:
                     d1["line_style"]="-"
                 if len(d1["line_width"])==0:
@@ -794,6 +798,8 @@ def plot_defect_densities(plot_params_in={}):
                 if len(d1["line_color"])==0:
                     d1["line_color"]=default_color[icolor]
                     icolor+=1
+                    if icolor==len(default_color):
+                        icolor=0
                 if len(d1["line_style"])==0:
                     d1["line_style"]="-"
                 if len(d1["line_width"])==0:
@@ -823,6 +829,8 @@ def plot_defect_densities(plot_params_in={}):
                 if len(d1["line_color"])==0:
                     d1["line_color"]=default_color[icolor]
                     icolor+=1
+                    if icolor==len(default_color):
+                        icolor=0
                 if len(d1["line_style"])==0:
                     d1["line_style"]="-"
                 if len(d1["line_width"])==0:
@@ -852,6 +860,8 @@ def plot_defect_densities(plot_params_in={}):
                 if len(d1["line_color"])==0:
                     d1["line_color"]=default_color[icolor]
                     icolor+=1
+                    if icolor==len(default_color):
+                        icolor=0
                 if len(d1["line_style"])==0:
                     d1["line_style"]="-"
                 if len(d1["line_width"])==0:
@@ -880,6 +890,8 @@ def plot_defect_densities(plot_params_in={}):
                 if len(d1["line_color"])==0:
                     d1["line_color"]=default_color[icolor]
                     icolor+=1
+                    if icolor==len(default_color):
+                        icolor=0
                 if len(d1["line_style"])==0:
                     d1["line_style"]="-"
                 if len(d1["line_width"])==0:
@@ -915,6 +927,8 @@ def plot_defect_densities(plot_params_in={}):
                 if len(d1["line_color"])==0:
                     d1["line_color"]=default_color[icolor]
                     icolor+=1
+                    if icolor==len(default_color):
+                        icolor=0
                 if len(d1["line_style"])==0:
                     d1["line_style"]="-"
                 if len(d1["line_width"])==0:
